# Generated by Django 3.1.6 on 2021-06-09 12:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('smsru', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='log',
            options={'ordering': ('-created_at',), 'verbose_name': 'Логи', 'verbose_name_plural': 'Лог'},
        ),
        migrations.AlterField(
            model_name='log',
            name='cost',
            field=models.FloatField(blank=True, null=True, verbose_name='Стоимость'),
        ),
        migrations.AlterField(
            model_name='log',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, verbose_name='Дата создания'),
        ),
        migrations.AlterField(
            model_name='log',
            name='msg',
            field=models.TextField(verbose_name='Сообщение'),
        ),
        migrations.AlterField(
            model_name='log',
            name='phone',
            field=models.CharField(max_length=30, verbose_name='Номер телефона'),
        ),
        migrations.AlterField(
            model_name='log',
            name='status',
            field=models.CharField(max_length=10, verbose_name='Статус'),
        ),
        migrations.AlterField(
            model_name='log',
            name='status_code',
            field=models.IntegerField(verbose_name='Код статуса'),
        ),
        migrations.AlterField(
            model_name='log',
            name='status_text',
            field=models.TextField(blank=True, null=True, verbose_name='Текст статуса'),
        ),
    ]
