# Generated by Django 3.1.5 on 2021-01-18 23:41

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Log',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('phone', models.CharField(max_length=30, verbose_name='Phone number')),
                ('msg', models.TextField(verbose_name='Message')),
                ('status', models.CharField(max_length=10, verbose_name='Status')),
                ('status_code', models.IntegerField(verbose_name='Status code')),
                ('status_text', models.TextField(blank=True, null=True, verbose_name='Status text')),
                ('sms_id', models.CharField(blank=True, max_length=255, null=True, verbose_name='SMS ID')),
                ('cost', models.FloatField(blank=True, null=True, verbose_name='Cost')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Created at')),
            ],
            options={
                'verbose_name': 'Logs',
                'verbose_name_plural': 'Log',
                'ordering': ('-created_at',),
            },
        ),
    ]
